@@ -50,68 +50,34 @@
 ComputeMST <- function(x, verbose=TRUE, scale=FALSE) {
   # returns a mst/df object
   data_aux <- data_check(x)
-  
-  if(isFALSE(scale)){
-    if(isFALSE(verbose)) {
-      BBmisc::suppressAll(
-        from_to_matrix <- mlpack_mst(data_aux) # always scaled  
-      )} else {
-        from_to_matrix <- mlpack_mst(data_aux) # always scaled  
-      } # as suggested at: https://github.com/rcppmlpack/RcppMLPACK1/issues/7
-    
-    from <- c(as.integer(from_to_matrix[1,]), 
-              1 ) # repeating the last link 
-    #.. for plots with ggplot2
-    to <- c(as.integer(from_to_matrix[2,]), 
-            1 ) # it should not be 
-    #.. "from" 1 "to" 1 in order to get stat_MST working
-    distance <- c(from_to_matrix[3,], 0) # adding a zero to the last row's 
-    #.. distance to not intefere in the total cost of the MST
-    
-    colnames(data_aux) <- colnames(as.data.frame(x))
-    # forcing as a data.frame because sometimes it's a matrix with no colnames
-    # we can't recover the rownames because sometimes data_check() may remove 
-    #.. lines with NA in the data
-    
-    
-    
-  } else {
-    
+
+  if (scale) {
     data_aux <- scale(data_aux)
-    
-    if(isFALSE(verbose)) {
-      BBmisc::suppressAll(
-        from_to_matrix <- mlpack_mst(data_aux) # always scaled  
-      )} else {
-        from_to_matrix <- mlpack_mst(data_aux) # always scaled  
-      } # as suggested at: https://github.com/rcppmlpack/RcppMLPACK1/issues/7  
-    
-    from <- c(as.integer(from_to_matrix[1,]), 
-              1 ) # repeating the last link 
-    #.. for plots with ggplot2
-    to <- c(as.integer(from_to_matrix[2,]), 
-            1 ) # it should not be 
-    #.. "from" 1 "to" 1 in order to get stat_MST working
-    distance <- c(from_to_matrix[3,], 0) # adding a zero to the last row's 
-    #.. distance to not intefere in the total cost of the MST
-    
-    colnames(data_aux) <- paste0("scaled_", colnames(as.data.frame(x)))
-    # forcing as a data.frame because sometimes it's a matrix with no colnames
-    # we can't recover the rownames because sometimes data_check() may remove 
-    #.. lines with NA in the data
-    
-    
   }
-  
-  x <- data.frame(data_aux, from, to, distance) # from and to are not linked 
+
+  from_to_matrix <- mlpack::emst(data_aux, verbose = verbose)$output # always scaled
+
+  from <- c(as.integer(from_to_matrix[,1]) + 1,
+            1 ) # repeating the last link
+  #.. for plots with ggplot2
+  to <- c(as.integer(from_to_matrix[,2]) + 1,
+          1 ) # it should not be
+  #.. "from" 1 "to" 1 in order to get stat_MST working
+  distance <- c(from_to_matrix[,3], 0) # adding a zero to the last row's
+  #.. distance to not intefere in the total cost of the MST
+
+  colnames(data_aux) <- colnames(as.data.frame(x))
+  # forcing as a data.frame because sometimes it's a matrix with no colnames
+  # we can't recover the rownames because sometimes data_check() may remove
+  #.. lines with NA in the data
+
+  x <- data.frame(data_aux, from, to, distance) # from and to are not linked
   #..to the rows
   # we just cbind from and to in order to have a data.frame and not a list
-  
+
   rm(data_aux) # cleaning
-  class(x) <- c("MST", "data.frame") # because we wanted a new plot.method for 
+  class(x) <- c("MST", "data.frame") # because we wanted a new plot.method for
   #..objects of class "MST".
-  
-  
-  
+
   return(x)
-}
\ No newline at end of file
+}
